import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../../../equipo/entity/equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { Prestamo } from '../prestamo.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';
import { Usuario } from '../../../usuario/entity/usuario.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('p.id_prestamo', 'id_prestamo')
      .addSelect('p.activo', 'activo')
      .addSelect('p.cancelado_operador', 'cancelado_operador')
      .addSelect('p.cancelado_usuario', 'cancelado_usuario')
      .addSelect('p.fecha_entrega', 'fecha_entrega')
      .addSelect('p.fecha_inicio', 'fecha_inicio')
      .addSelect('p.hora_fin', 'hora_fin')
      .addSelect('p.hora_inicio', 'hora_inicio')
      .addSelect('p.hora_max_recoger', 'hora_max_recoger')
      .addSelect('p.id_equipo', 'id_equipo')
      .addSelect('p.id_usuario', 'id_usuario')
      .addSelect('e.equipo', 'equipo')
      .addSelect('e.u', 'u')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.numero_inventario', 'numero_inventario')
      .addSelect('u.id_tipo_usuario', 'id_tipo_usuario')
      .addSelect('u.nombre', 'nombre')
      .addSelect('u.usuario', 'usuario')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('m.id_institucion', 'id_institucion')
      .addSelect('m.modulo', 'modulo')
      .addSelect('tc.tipo_carrito', 'tipo_carrito')
      .addSelect('i.institucion', 'institucion')
      .from(Prestamo, 'p')
      .innerJoin(Equipo, 'e', 'e.id_equipo = p.id_equipo')
      .innerJoin(Usuario, 'u', 'u.id_usuario = p.id_usuario')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion'),
})
export class PrestamoInformacionView {
  @ViewColumn()
  id_prestamo: number;

  @ViewColumn()
  activo: number;

  @ViewColumn()
  cancelado_operador: number;

  @ViewColumn()
  cancelado_usuario: number;

  @ViewColumn()
  carrito: string;

  @ViewColumn()
  equipo: string;

  @ViewColumn()
  fecha_entrega: Date;

  @ViewColumn()
  fecha_inicio: Date;

  @ViewColumn()
  hora_fin: Date;

  @ViewColumn()
  hora_inicio: Date;

  @ViewColumn()
  hora_max_recoger: Date;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_tipo_usuario: number;

  @ViewColumn()
  id_usuario: number;

  @ViewColumn()
  institucion: string;

  @ViewColumn()
  modulo: string;

  @ViewColumn()
  nombre: string;

  @ViewColumn()
  numero_inventario: string;

  @ViewColumn()
  tipo_carrito: string;

  @ViewColumn()
  usuario: string;

  @ViewColumn()
  u: number;
}
